pub struct DataClassAnalyzer {
pub min_fields: usize,
}Expand description
Detect classes that only have fields and accessor methods (no real behavior).
Fields
min_fields: usizeTrait Implementations
Sourceimpl Default for DataClassAnalyzer
impl Default for DataClassAnalyzer
Sourceimpl Plugin for DataClassAnalyzer
impl Plugin for DataClassAnalyzer
Sourcefn description(&self) -> &str
fn description(&self) -> &str
Short description of what the plugin detects.
Sourcefn analyze(&self, ctx: &AnalysisContext<'_>) -> Vec<Finding>
fn analyze(&self, ctx: &AnalysisContext<'_>) -> Vec<Finding>
Run analysis on a single file and return findings.
List of authors.