pub struct FeatureEnvyAnalyzer {
pub min_refs: usize,
pub external_ratio: f64,
}Expand description
Detect methods that reference external objects more than their own.
Fields
min_refs: usizeexternal_ratio: f64Trait Implementations
Sourceimpl Default for FeatureEnvyAnalyzer
impl Default for FeatureEnvyAnalyzer
Sourceimpl Plugin for FeatureEnvyAnalyzer
impl Plugin for FeatureEnvyAnalyzer
Sourcefn description(&self) -> &str
fn description(&self) -> &str
Short description of what the plugin detects.
Sourcefn analyze(&self, ctx: &AnalysisContext<'_>) -> Vec<Finding>
fn analyze(&self, ctx: &AnalysisContext<'_>) -> Vec<Finding>
Run analysis on a single file and return findings.
List of authors.