pub struct GodClassAnalyzer {
pub max_external_refs: usize,
pub min_wmc: usize,
}Expand description
Detect God Classes using the detection strategy from [1]:
(ATFD > Few) AND (WMC >= VeryHigh) AND (TCC < 1/3)
References
[1] M. Lanza and R. Marinescu, “Object-Oriented Metrics in Practice: Using Software Metrics to Characterize, Evaluate, and Improve the Design of Object-Oriented Systems,” Springer, 2006. doi: 10.1007/3-540-39538-5. Chapter 6.1, pp. 79–83. Thresholds derived from Table A.2 (45 Java projects).
Fields
max_external_refs: usizeATFD threshold: Access to Foreign Data (Few = 5)
min_wmc: usizeWMC threshold: Weighted Method Count (VeryHigh = 47)