pub struct LazyClassAnalyzer {
pub max_methods: usize,
pub max_lines: usize,
}Expand description
Detect classes with very few methods and lines (nearly empty wrappers).
Fields
max_methods: usizemax_lines: usizeTrait Implementations
Sourceimpl Default for LazyClassAnalyzer
impl Default for LazyClassAnalyzer
Sourceimpl Plugin for LazyClassAnalyzer
impl Plugin for LazyClassAnalyzer
Sourcefn description(&self) -> &str
fn description(&self) -> &str
Short description of what the plugin detects.
Sourcefn analyze(&self, ctx: &AnalysisContext<'_>) -> Vec<Finding>
fn analyze(&self, ctx: &AnalysisContext<'_>) -> Vec<Finding>
Run analysis on a single file and return findings.
List of authors.