pub struct MiddleManAnalyzer {
pub min_methods: usize,
pub delegation_ratio: f64,
}Expand description
Detect classes where most methods only delegate to another object.
Fields
min_methods: usizedelegation_ratio: f64Trait Implementations
Sourceimpl Default for MiddleManAnalyzer
impl Default for MiddleManAnalyzer
Sourceimpl Plugin for MiddleManAnalyzer
impl Plugin for MiddleManAnalyzer
Sourcefn description(&self) -> &str
fn description(&self) -> &str
Short description of what the plugin detects.
Sourcefn analyze(&self, ctx: &AnalysisContext<'_>) -> Vec<Finding>
fn analyze(&self, ctx: &AnalysisContext<'_>) -> Vec<Finding>
Run analysis on a single file and return findings.
List of authors.