pub struct TemporaryFieldAnalyzer {
pub min_methods: usize,
pub max_usage_ratio: f64,
}Expand description
Detect fields that are only used in a small fraction of methods.
Fields
min_methods: usizemax_usage_ratio: f64Trait Implementations
Sourceimpl Default for TemporaryFieldAnalyzer
impl Default for TemporaryFieldAnalyzer
Sourceimpl Plugin for TemporaryFieldAnalyzer
impl Plugin for TemporaryFieldAnalyzer
Sourcefn description(&self) -> &str
fn description(&self) -> &str
Short description of what the plugin detects.
Sourcefn analyze(&self, ctx: &AnalysisContext<'_>) -> Vec<Finding>
fn analyze(&self, ctx: &AnalysisContext<'_>) -> Vec<Finding>
Run analysis on a single file and return findings.
List of authors.