Structs
- Analysis
Input - Full analysis context passed to the plugin.
- Class
Info - Class info from parsed source.
- Comment
Info - Comment info from parsed source.
- Finding
- A single finding.
- Function
Info - Function info from parsed source.
- Import
Info - Import info.
- Location
- Source location.
- TypeRef
- A function parameter or return type, with resolved origin.
Enums
- ArmValue
- Switch/match arm value type.
- File
Role - File role inferred by the host from path patterns.
- Option
Value - Typed option value for plugin configuration.
- Severity
- Severity level.
- Smell
Category - Smell category.
- Type
Origin - Where a referenced type is declared.