Crate cha_core

Crate cha_core 

Re-exports

pub use config::Config;
pub use config::DebtWeights;
pub use config::LanguageConfig;
pub use config::Strictness;
pub use config::builtin_language_profile;
pub use reporter::JsonReporter;
pub use reporter::LlmContextReporter;
pub use reporter::Reporter;
pub use reporter::SarifReporter;
pub use reporter::TerminalReporter;

Modules

config
html_reporter
plugins
reporter
wasm

Structs

AnalysisCache
Incremental analysis cache.
AnalysisContext
Analysis context passed to plugins.
Baseline
A baseline is a set of finding fingerprints representing known/accepted issues.
ClassInfo
Extracted class/struct info from AST.
CommentInfo
A comment extracted from source code by the language parser.
Finding
A single analysis finding.
FunctionInfo
Extracted function info from AST.
HealthScore
Per-file health score.
ImportInfo
Extracted import info.
Location
Source location of a finding.
PluginRegistry
Manages plugin registration and lifecycle.
SourceFile
Raw source file content.
SourceModel
Unified source model produced by parsing.

Enums

Grade
Health grade A–F for a file, based on issue density.
Severity
Severity level for a finding.
SmellCategory
Smell category from refactoring literature.

Traits

Plugin
Core trait that all analyzers implement.

Functions

filter_ignored
Filter out findings suppressed by cha:ignore comments in source code, and re-evaluate findings against cha:set threshold overrides.
findings_json_schema
Generate JSON Schema for the analysis output (list of findings).
score_files
Compute health scores grouped by file.