Re-exports
pub use config::Config;pub use config::DebtWeights;pub use config::LanguageConfig;pub use config::Strictness;pub use config::builtin_language_profile;pub use reporter::JsonReporter;pub use reporter::LlmContextReporter;pub use reporter::Reporter;pub use reporter::SarifReporter;pub use reporter::TerminalReporter;
Modules
Structs
- Analysis
Cache - Incremental analysis cache.
- Analysis
Context - Analysis context passed to plugins.
- Baseline
- A baseline is a set of finding fingerprints representing known/accepted issues.
- Class
Info - Extracted class/struct info from AST.
- Comment
Info - A comment extracted from source code by the language parser.
- Finding
- A single analysis finding.
- Function
Info - Extracted function info from AST.
- Health
Score - Per-file health score.
- Import
Info - Extracted import info.
- Location
- Source location of a finding.
- Plugin
Registry - Manages plugin registration and lifecycle.
- Source
File - Raw source file content.
- Source
Model - Unified source model produced by parsing.
Enums
- Grade
- Health grade A–F for a file, based on issue density.
- Severity
- Severity level for a finding.
- Smell
Category - Smell category from refactoring literature.
Traits
- Plugin
- Core trait that all analyzers implement.
Functions
- filter_
ignored - Filter out findings suppressed by
cha:ignorecomments in source code, and re-evaluate findings againstcha:setthreshold overrides. - findings_
json_ schema - Generate JSON Schema for the analysis output (list of findings).
- score_
files - Compute health scores grouped by file.